pub async fn stats(db: &DB)Expand description
Fetch and display database statistics
Fetches statistics about the database, including the number of rows and estimated size for each table, and prints them to the console.
Arguments
db- A reference to the database connection.
Example
let db = DB::connect("database_url").await?;
db::stats(&db).await;